StringChars

Struct StringChars 

pub struct StringChars<'env> { /* private fields */ }
Represents a JNI GetStringChars + GetStringLength query. It will call ReleaseStringChars automatically when dropped.

Implementations

Source

impl<'env> StringChars<'env>

pub unsafe fn from_env_jstring(env: Env<'env>, string: jstring) -> Self

Construct a StringChars from an Env + jstring.

Safety

The Java string object referenced by string must remain available before the created StringChars is dropped. This should be true if the JNI reference string is not deleted.

This function is supposed to be used in generated bindings.

pub fn chars(&self) -> &[jchar]

Get an array of jchars. Generally UTF16, but not guaranteed to be valid UTF16.

pub fn decode(&self) -> DecodeUtf16<Cloned<Iter<'_, u16>>>

std::char::decode_utf16(…)s these string characters.

pub fn to_string(&self) -> Result<String, DecodeUtf16Error>

Returns a new Ok(String), or an Err(DecodeUtf16Error) if if it contained any invalid UTF16.

pub fn to_string_lossy(&self) -> String

Returns a new String with any invalid UTF16 characters replaced with REPLACEMENT_CHARACTERs ('\u{FFFD}'.)