AsArg

Trait AsArg 

pub unsafe trait AsArg<T>: Sized + AsJValue {
    // Required method
    fn as_arg(&self) -> jobject;
}
A marker trait indicating this is a valid JNI reference type for Java method argument type T, this can be null.

Safety

It should be implemented automatically by java_oxide.

Required Methods

fn as_arg(&self) -> jobject

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: ReferenceType, U: AsArg<T>> AsArg<T> for &U

Source

fn as_arg(&self) -> jobject

Source

impl<T: ReferenceType, U: AsArg<T>> AsArg<T> for &mut U

Source

fn as_arg(&self) -> jobject

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Option<&Global<U>>

Source

fn as_arg(&self) -> jobject

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Option<&Local<'_, U>>

Source

fn as_arg(&self) -> jobject

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Option<&Ref<'_, U>>

Source

fn as_arg(&self) -> jobject

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Option<Global<U>>

Source

fn as_arg(&self) -> jobject

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Option<Local<'_, U>>

Source

fn as_arg(&self) -> jobject

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Option<Ref<'_, U>>

Source

fn as_arg(&self) -> jobject

Implementors

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Global<U>

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Local<'_, U>

Source

impl<T: ReferenceType, U: AssignableTo<T>> AsArg<T> for Ref<'_, U>

Source

impl<T: ReferenceType> AsArg<T> for Null